searchData={"items":[{"type":"module","title":"Compox","doc":"Module to work with a Docker environment for testing.\n\nCompox starts Docker containers when the application starts (see\n[configuration](#configuration) for more info).","ref":"Compox.html"},{"type":"module","title":"Containers availability - Compox","doc":"Compox makes two checks to ensure the containers are available:\n\n* the container has `running` status.\n* the exposed ports to the host, if any, accept connections.","ref":"Compox.html#module-containers-availability"},{"type":"module","title":"Configuration - Compox","doc":"* `auto_start`: Whether the docker compose services should start with this\napplication. Defaults to `true`.\n\n* `auto_stop`: Whether the docker compose services should stop after the tests.\nDefaults to `true`.\n\n* `exclude`: The list of Docker services to exclude. These services won't be\nstarted by Compox.\n\n* `container_upchecks`: Keyword list of functions that will be used to check\nif a container an _up_ state. See `Compox.Docker.Containers` documentation for\nmore info.\n\n* `kill_on_finish`: Kills the containers instead of stopping them.","ref":"Compox.html#module-configuration"},{"type":"module","title":"Container upchecks - Compox","doc":"There are containers that need more checks rather than just accepting\nconnection on a port. In those cases, you can use `container_upchecks` config\nand provide a function that will be reevaluated until it returns `:ok`.\n\n#### Example: checking Postgres connection\n\nIf you use a PostgreSQL containers, you will need to ensure that ecto will be\nable to connect to the container before running the tests. In the following\nexample, we will be using `Postgrex.Protocol.connect/1` to attempt a\nconnection to the database. The _upcheck function_ will check whether the\nPostgres connection returned an application (invalid credentials, unknown\n  catalog...) or a connection error.","ref":"Compox.html#module-container-upchecks"},{"type":"function","title":"Compox.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Compox.html#child_spec/1"},{"type":"function","title":"Compox.stop/0","doc":"Stops all the started containers.\n\nAny container started using the `docker-compose.yml` will be stopped.","ref":"Compox.html#stop/0"},{"type":"module","title":"Compox.Docker.Compose","doc":"Module that provides functions to interact with Docker and `docker-compose`\nfiles.","ref":"Compox.Docker.Compose.html"},{"type":"function","title":"Compox.Docker.Compose.up/1","doc":"Start services listed on the `docker-compose.yml` file.","ref":"Compox.Docker.Compose.html#up/1"},{"type":"module","title":"Compox.Docker.Services","doc":"Provides functions to work with [Compox\nservices](`Compox.Docker.Services.Service`).","ref":"Compox.Docker.Services.html"},{"type":"function","title":"Compox.Docker.Services.start/1","doc":"Starts [services](`t:Compox.Docker.Service.t/0`) from the `docker compose`.\n\nEach service is started independently.\n\nAfter all services are launch, returns the list of services updated with each\ncontainer id.","ref":"Compox.Docker.Services.html#start/1"},{"type":"function","title":"Compox.Docker.Services.stop/1","doc":"Stops the given [services](`t:Compox.Docker.Service.t/0`).\n\nIn order to stop the containers, sends a `SIGKILL` message to all the\ncontainer process.","ref":"Compox.Docker.Services.html#stop/1"},{"type":"module","title":"Compox.Docker.Services.Service","doc":"Represents a [Docker service](https://docs.docker.com/get-started/part3/).","ref":"Compox.Docker.Services.Service.html"},{"type":"type","title":"Compox.Docker.Services.Service.t/0","doc":"A internal representation of a Docker service present in a `docker-compose`\nfile:\n\n* `name`: The name of the Docker service.\n* `image`: The Docker image used by the service.\n* `container_id`: The `id` of the Docker container.\n* `container_name`: The name of the service container, defaults to `nil`.\n* `reused`: Whether the container running this service was already created or\nrunning.","ref":"Compox.Docker.Services.Service.html#t:t/0"},{"type":"behaviour","title":"Compox.Upcheck","doc":"Module that provides callback definitions to run containers upchecks.","ref":"Compox.Upcheck.html"},{"type":"callback","title":"Compox.Upcheck.upcheck/1","doc":"","ref":"Compox.Upcheck.html#c:upcheck/1"},{"type":"module","title":"Compox.Upchecks.Postgrex","doc":"Module that provides the upcheck implementation to ensure a Postgres\nconnection can be used.\n\nThis module tries to connect to a Postgres database, and it will succeed if\nthe connection can be established and a credentials error is returned.","ref":"Compox.Upchecks.Postgrex.html"},{"type":"module","title":"Configuration - Compox.Upchecks.Postgrex","doc":"`Elixir.Compox.Upchecks.Postgrex` supports the following args:\n\n  * `hostname`: The hostname to check the connection. Defaults to `localhost`.\n\n```elixir\nconfig :compox,\n  container_upchecks: [\n    \"postgres\": {Compox.Upchecks.Postgrex, []}\n  ]\n```","ref":"Compox.Upchecks.Postgrex.html#module-configuration"},{"type":"task","title":"mix compox.down","doc":"","ref":"Mix.Tasks.Compox.Down.html"},{"type":"function","title":"Mix.Tasks.Compox.Down.run/1","doc":"","ref":"Mix.Tasks.Compox.Down.html#run/1"},{"type":"task","title":"mix compox.up","doc":"","ref":"Mix.Tasks.Compox.Up.html"},{"type":"function","title":"Mix.Tasks.Compox.Up.run/1","doc":"","ref":"Mix.Tasks.Compox.Up.html#run/1"},{"type":"extras","title":"README","doc":"[![Hex version](https://img.shields.io/hexpm/v/sippet.svg \"Hex version\")](https://hex.pm/packages/compox)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-9768d1.svg)](https://hexdocs.pm/compox)\n\n# Compox","ref":"readme.html"},{"type":"extras","title":"Introduction - README","doc":"Compox ensure your whole infrastructure is up before running the tests.\n\nCompox helps you to setup an ephemeral environment to run your tests using the\n`docker-compose.yml` present in your project. After all your tests are done,\nit will take the test environment down. This way your machine won't waste\nresources having the containers running when they are not needed.","ref":"readme.html#introduction"},{"type":"extras","title":"Features - README","doc":"- Reuse created/running containers for other projects (e.g. shared database)\n- Automatic start of the required container services\n- Automatic stop of the required container services","ref":"readme.html#features"},{"type":"extras","title":"Installation - README","doc":"Adding `compox` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:compox, \"~> 0.1.0-rc3\", only: [:test]}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"To use Compox follow these steps:\n\n- Create a `docker-compose.yml` file with the containers that will be started\n  by this application.\n\n- Ensure Compox starts all containers before running the tests:\n\n```elixir\ndefp aliases do\n  [\n    test: [\"compox.up\", \"ecto.create --quiet\", \"ecto.migrate --quiet\", \"test\"]\n  ]\nend\n```\n\n- Edit your `test_helper.exs` to stop the containers after the tests are\n  done:\n\n```elixir\nExUnit.after_suite(fn _ ->\n  Compox.stop()\nend)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Upchecks - README","doc":"Sometimes a container is started by it takes a while to be ready to be used by\nyour application. For example, a database container can be started by the\ndatabase will take few seconds to start accepting connections.\n\nTo avoid any errors, Compox supports _upchecks_ probe configurations to validate\nwhether a container can be used or not.\n\nYou can implement your own logic to validate if a container is ready (see\nexample below) or use the default provided upchecks:\n\n* `Postgres`: `Compox.Upchecks.Postgrex`","ref":"readme.html#upchecks"},{"type":"extras","title":"Example - README","doc":"Compox allows you to configure a project to start/stop the containers to run the\ntests, but also provides configuration to **work with any kind of situation**.\n\nFor example, some of or coworkers prefer to have the containers running all the\ntime. In this case you want to ensure the docker containers are started before the test, so people that prefer to save resources will start the containers, but you will also won't to avoid to take containers down.\n\nYou `config/test.exs` file will look like:\n\n```elixir\nuse Mix.Config\n\nconfig :compox,\n  auto_start: true,\n  auto_stop: false,\n  exclude: [\"a_service_should_not_be_started\"],\n  container_upchecks: [\n    \"postgres-service\": {Compox.Upchecks.Postgrex, []},\n    another_service: fn ->\n      Another.Connection.up?()\n    end\n  ]\n```\n\nThe people who will want to stop the containers after test can use a [_dotenv_\nlibrary](https://github.com/BlakeWilliams/envy) to change the `auto_stop` config to `true` on their machines.\n\n> This can work the other way around, start/stopping the containers always and\n> having `dotfile` config to skipping the start/stop.","ref":"readme.html#example"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}